@@ -1,8 +1,6 @@
 from __future__ import annotations
 
 import os
-import platform
-import sys
 import zipfile
 
 from contextlib import contextmanager
@@ -10,8 +8,6 @@ from pathlib import Path
 from typing import TYPE_CHECKING
 from typing import Iterator
 
-import pytest
-
 from poetry.core import __version__
 from poetry.core.masonry import api
 from poetry.core.utils.helpers import temporary_directory
@@ -88,12 +84,6 @@ def test_build_wheel_with_bad_path_dep_succeeds(caplog: LogCaptureFixture) -> No
     assert "does not exist" in record.message
 
 
-@pytest.mark.skipif(
-    sys.platform == "win32"
-    and sys.version_info <= (3, 6)
-    or platform.python_implementation().lower() == "pypy",
-    reason="Disable test on Windows for Python <=3.6 and for PyPy",
-)
 def test_build_wheel_extended() -> None:
     with temporary_directory() as tmp_dir, cwd(os.path.join(fixtures, "extended")):
         filename = api.build_wheel(tmp_dir)
@@ -177,6 +167,7 @@ Classifier: Programming Language :: Python :: 3.8
 Classifier: Programming Language :: Python :: 3.9
 Classifier: Programming Language :: Python :: 3.10
 Classifier: Programming Language :: Python :: 3.11
+Classifier: Programming Language :: Python :: 3.12
 Classifier: Topic :: Software Development :: Build Tools
 Classifier: Topic :: Software Development :: Libraries :: Python Modules
 Provides-Extra: time
@@ -191,7 +182,7 @@ Description-Content-Type: text/x-rst
 My Package
 ==========
 
-"""  # noqa: E501
+"""
     with temporary_directory() as tmp_dir, cwd(os.path.join(fixtures, "complete")):
         dirname = api.prepare_metadata_for_build_wheel(tmp_dir)
 
@@ -261,7 +252,7 @@ def test_build_wheel_with_metadata_directory() -> None:
 
         with temporary_directory() as wheel_tmp_dir:
             dist_info_path = Path(metadata_tmp_dir) / metadata_directory
-            open(dist_info_path / "CUSTOM", "w").close()  # noqa: SIM115
+            (dist_info_path / "CUSTOM").touch()
             filename = api.build_wheel(
                 wheel_tmp_dir, metadata_directory=str(dist_info_path)
             )
@@ -288,7 +279,7 @@ def test_build_editable_wheel_with_metadata_directory() -> None:
 
         with temporary_directory() as wheel_tmp_dir:
             dist_info_path = Path(metadata_tmp_dir) / metadata_directory
-            open(dist_info_path / "CUSTOM", "w").close()  # noqa: SIM115
+            (dist_info_path / "CUSTOM").touch()
             filename = api.build_editable(
                 wheel_tmp_dir, metadata_directory=str(dist_info_path)
             )
